summaryrefslogtreecommitdiffstats
path: root/testserver.pl
diff options
context:
space:
mode:
Diffstat (limited to 'testserver.pl')
-rwxr-xr-xtestserver.pl8
1 files changed, 4 insertions, 4 deletions
diff --git a/testserver.pl b/testserver.pl
index d3cab1dc5..f7949948f 100755
--- a/testserver.pl
+++ b/testserver.pl
@@ -86,14 +86,14 @@ to validate webservergroup.\n";
}
# Try to fetch a static file (front.png)
$ARGV[0] =~ s/\/$//;
-my $url = $ARGV[0] . "/skins/standard/index/front.png";
+my $url = $ARGV[0] . "/images/padlock.png";
if (fetch($url)) {
- print "TEST-OK Got front picture.\n";
+ print "TEST-OK Got padlock picture.\n";
} else {
print
-"TEST-FAILED Fetch of skins/standard/index/front.png failed
+"TEST-FAILED Fetch of images/padlock.png failed
Your web server could not fetch $url.
Check your web server configuration and try again.\n";
exit(1);
@@ -86,14 +86,14 @@ to validate webservergroup.\n";
}
-# Try to fetch a static file (front.png)
+# Try to fetch a static file (padlock.png)
$ARGV[0] =~ s/\/$//;